package java.de.TimeSlice;

import java.util.*;

/**
 * @author      Burghard Grueter
 * @author      Johannes Schick
 * @version     1.0, 11/06/2000
 * @since       JDK1.2
 */
 
	/**
	 * class <pre>Task</pre> contains all the 
	 * data important for a task and implements
	 * all methods to process the tasks with 
	 * <pre>TimeSlice</pre>. It implements
	 * the interface <pre>TaskData</pre> providing
	 * a readonly-access to the data whereby
	 * conform with information-hiding
	 */
public class Task implements TaskData
{
	private String TaskName;
	
	private long Start;
	private long Dauer;
	private long Restdauer;
	private long Periode;
	
	private boolean active;
	
	private UpdateTaskListener Listen;
	
	public Task(String TaskName, long Start, long Dauer, long Restdauer, long Periode, boolean active) 
	{
	  assign(TaskName, Dauer, Periode);
	  			   
	  this.Start = Start;
	  this.Restdauer = Restdauer;
	  
	  this.active = active;
	  this.Listen = null;
	}
	
	public Task(String TaskName, long Dauer, long Periode) {
	  this(TaskName, (new Date()).getTime(), Dauer, Dauer, Periode, false);
	
	}
	

	/**
	 * assign the given Values to the property fields of the instance
	 * hereby data is changed and the Listener's method is called
	 *
	 * @param   TaskName  
	 * @param   Dauer  
	 * @param   Periode  
	 */
	public void assign(String TaskName, long Dauer, long Periode)
	{
		this.TaskName = TaskName;
		this.Dauer = Dauer;
		this.Periode = Periode;
		this.Restdauer = Dauer;
		this.Start = (new Date()).getTime();
		if (Listen!=null)
  		  Listen.updateTaskPanel();
	}
				

	/**
	 * adds a UpdateTaskListener to the instance. Its method
	 * <pre>updateTaskPanel()</pre> is called when the data
	 * or the status changes
	 *
	 * @param   uptlNeu  
	 */
	public void addUpdateTaskListener(UpdateTaskListener uptlNeu) 
	{
	   this.Listen = uptlNeu;
	}
					
	public String getTaskName () 
	{
		return this.TaskName;
	}
		
	public void setTaskName (String Value) 
	{
		this.TaskName = Value;
	}
	
	public long getStart () 
	{
	 	return this.Start;	
	}
		
	public void setStart (long Value) 
	{
		this.Start = Value;
	}

	public long getDauer () 
	{
	  	return this.Dauer;	
	}
	
	public void setDauer (long Value) 
	{ 
	 	this.Dauer = Value;	
	}

	public long getPeriode () 
	{
		return this.Periode;
	}

	public void setPeriode (long Value) 
	{
		this.Periode= Value;
	}

	public long getRestdauer () 
	{
		return this.Restdauer;
	}

	public void setRestdauer (long Value) 
	{
		this.Restdauer = Value;
	}
	
	public void mindereRestdauer(long delta)
	{
		this.Restdauer -= delta;
		if (Listen!=null)
  		  Listen.updateTaskPanel();
	}

	public boolean isActive () 
	{
		return this.active;
	}

	public void setActive (boolean active) 
	{
		this.active = active;
		if (Listen!=null)
  		  Listen.updateTaskPanel();
	}
	
	public void reset()
	{
	}

}

