package java.de.TimeSlice;

import java.awt.event.*;
import javax.swing.Timer;
import java.util.Date;

/**
 * @author      Burghard Grueter
 * @author      Johannes Schick
 * @version     1.0, 11/06/2000
 * @since       JDK1.2
 */
	/**
	 * class <pre>TaskTimer</pre> calls
	 * periodically update-methods accessed by
	 * the owned <pre>TimerListener</pre> interface	
	 */
public class TaskTimer implements ActionListener
{

	final static long DAY = 86400000;
	final static long HOUR = 3600000;
	
	private Date last;
	
	private Timer myTimer;
	
	private TimerListener tListen=null;
	

	/**
	 * 
	 *
	 * @param   tListen  class, which wants have its update methods called
	 *					 periodically
	 */
	public TaskTimer(TimerListener tListen) 
	{	
		last = new Date();
		this.tListen = tListen;
		myTimer = new Timer(1000, this);
		myTimer.setRepeats(true);
	}
	

	/**
	 *	<pre>TaskTimer</pre> implements <pre>ActionListener</pre>
	 *	At each timer event <pre>actionPerformed</pre> is called.
	 *  The <pre>TaskTimer</pre> then calls the update functions
	 * 
	 * @param   e  
	 */
	public void actionPerformed(ActionEvent e)
	{
	 	Date t =  new Date(); // contains current date
		if (tListen!=null) // be sure!
		{
			
			tListen.updateActiveTask(t.getTime()-last.getTime());
		
			 if (t.getDay()!=last.getDay()) // only when day changes
				tListen.updateDayChange(t.getTime()); 
		}	
		
		last = t;  
								
	}	
	
	public void start() 
	{
	 	myTimer.start();
	}
	
	public void stop()
	{
		myTimer.stop();
	}

}

